==> aws-cdk-scala_2.12-0.8.0-sources.jar: io/burkard/cdk/services/amplify/CfnAppProps.scala <==
package io.burkard.cdk.services.amplify

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnAppProps {

  def apply(
    name: String,
    repository: Option[String] = None,
    description: Option[String] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    environmentVariables: Option[List[_]] = None,
    iamServiceRole: Option[String] = None,
    buildSpec: Option[String] = None,
    oauthToken: Option[String] = None,
    basicAuthConfig: Option[software.amazon.awscdk.services.amplify.CfnApp.BasicAuthConfigProperty] = None,
    customRules: Option[List[_]] = None,
    customHeaders: Option[String] = None,
    autoBranchCreationConfig: Option[software.amazon.awscdk.services.amplify.CfnApp.AutoBranchCreationConfigProperty] = None,
    enableBranchAutoDeletion: Option[Boolean] = None,
    accessToken: Option[String] = None
  ): software.amazon.awscdk.services.amplify.CfnAppProps =
    (new software.amazon.awscdk.services.amplify.CfnAppProps.Builder)
      .name(name)
      .repository(repository.orNull)
      .description(description.orNull)
      .tags(tags.map(_.asJava).orNull)
      .environmentVariables(environmentVariables.map(_.asJava).orNull)
      .iamServiceRole(iamServiceRole.orNull)
      .buildSpec(buildSpec.orNull)
      .oauthToken(oauthToken.orNull)
      .basicAuthConfig(basicAuthConfig.orNull)
      .customRules(customRules.map(_.asJava).orNull)
      .customHeaders(customHeaders.orNull)
      .autoBranchCreationConfig(autoBranchCreationConfig.orNull)
      .enableBranchAutoDeletion(enableBranchAutoDeletion.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .accessToken(accessToken.orNull)
      .build()
}

==> aws-cdk-scala_2.12-0.21.0-sources.jar: io/burkard/cdk/services/amplify/CfnAppProps.scala <==
package io.burkard.cdk.services.amplify

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnAppProps {

  def apply(
    name: String,
    repository: Option[String] = None,
    description: Option[String] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    environmentVariables: Option[List[_]] = None,
    iamServiceRole: Option[String] = None,
    buildSpec: Option[String] = None,
    oauthToken: Option[String] = None,
    basicAuthConfig: Option[software.amazon.awscdk.services.amplify.CfnApp.BasicAuthConfigProperty] = None,
    customRules: Option[List[_]] = None,
    customHeaders: Option[String] = None,
    autoBranchCreationConfig: Option[software.amazon.awscdk.services.amplify.CfnApp.AutoBranchCreationConfigProperty] = None,
    enableBranchAutoDeletion: Option[Boolean] = None,
    accessToken: Option[String] = None
  ): software.amazon.awscdk.services.amplify.CfnAppProps =
    (new software.amazon.awscdk.services.amplify.CfnAppProps.Builder)
      .name(name)
      .repository(repository.orNull)
      .description(description.orNull)
      .tags(tags.map(_.asJava).orNull)
      .environmentVariables(environmentVariables.map(_.asJava).orNull)
      .iamServiceRole(iamServiceRole.orNull)
      .buildSpec(buildSpec.orNull)
      .oauthToken(oauthToken.orNull)
      .basicAuthConfig(basicAuthConfig.orNull)
      .customRules(customRules.map(_.asJava).orNull)
      .customHeaders(customHeaders.orNull)
      .autoBranchCreationConfig(autoBranchCreationConfig.orNull)
      .enableBranchAutoDeletion(enableBranchAutoDeletion.map(Boolean.box).orNull)
      .accessToken(accessToken.orNull)
      .build()
}
